import axios from 'axios'
import apiConfig from './apiConfig'

const BASE_API = axios.create({
  baseURL: apiConfig.baseApiDomain,
  headers: {
    'Content-Type': 'application/json',
  },
})

BASE_API.postAsForm = async (url, data, options = {}) => {
  const bodyFormData = new FormData()

  Object.keys(data).forEach((key) => {
    createFormData(bodyFormData, data[key], key)
  })
  const response = await BASE_API.post(url, bodyFormData, {
    ...options,
    headers: {
      'Content-Type': 'multipart/form-data',
    },
  })
  return response
}

BASE_API.putAsForm = async (url, data, options = {}) => {
  const bodyFormData = new FormData()
  Object.keys(data).forEach((key) => {
    createFormData(bodyFormData, data[key], key)
  })
  const response = await BASE_API.put(url, bodyFormData, {
    ...options,
    headers: {
      'Content-Type': 'multipart/form-data',
    },
  })
  return response
}

function createFormData(formData, data, key) {
  if ((typeof data === 'object' && data !== null) || Array.isArray(data)) {
    if (data instanceof File) {
      formData.append(key, data)
    } else {
      // eslint-disable-next-line no-restricted-syntax
      for (const i in data) {
        if (
          (typeof data[i] === 'object' && data[i] !== null) ||
          Array.isArray(data[i])
        ) {
          if (data[i] instanceof File) {
            createFormData(formData, data[i], `${key}`)
          } else {
            createFormData(formData, data[i], `${key}[${i}]`)
          }
        } else {
          formData.append(`${key}[${i}]`, data[i])
        }
      }
    }
  } else {
    formData.append(key, data)
  }
}

export default BASE_API