import React, { useState } from 'react'
import {
  CFormGroup,
  CInput,
  CInputGroup,
  CInvalidFeedback
} from '@coreui/react'

const removeAccents = (str) => {
	if (str === '') return str
  let AccentsMap = [
    "aàảãáạăằẳẵắặâầẩẫấậ",
    "AÀẢÃÁẠĂẰẲẴẮẶÂẦẨẪẤẬ",
    "dđ", "DĐ",
    "eèẻẽéẹêềểễếệ",
    "EÈẺẼÉẸÊỀỂỄẾỆ",
    "iìỉĩíị",
    "IÌỈĨÍỊ",
    "oòỏõóọôồổỗốộơờởỡớợ",
    "OÒỎÕÓỌÔỒỔỖỐỘƠỜỞỠỚỢ",
    "uùủũúụưừửữứự",
    "UÙỦŨÚỤƯỪỬỮỨỰ",
    "yỳỷỹýỵ",
    "YỲỶỸÝỴ"
	]
  for (let i=0; i<AccentsMap.length; i++) {
    let re = new RegExp('[' + AccentsMap[i].substr(1) + ']', 'g')
    let char = AccentsMap[i][0]
    str = str.replace(re, char)
  }
  return str
}

const TextSearch = (props) => {
  const [focusIndex, setFocusIndex] = useState(-1)
  const [filteredSuggestions, setFilteredSuggesstions] = useState([])

  const onChangeValue = (e) => {
    const { target: { value }} = e
    props.onChange(e)
    filterSuggestion(value)
    setFocusIndex(-1)
  }

  const showAutocomplete = () => {
    filterSuggestion(props.value)
  }

  const filterSuggestion = (value) => {
    if (!value) return setFilteredSuggesstions(props.suggestions.slice(0, props.suggestionSize || 5))
    const regex = new RegExp(removeAccents(value).split``.join('.*'), 'i')
    setFilteredSuggesstions(
      props.suggestions.filter(sug => regex.test(removeAccents(sug))).slice(0, props.suggestionSize || 5)
    )
  }

  const keyDown = (e) => {
    switch (e.key) {
      case 'ArrowDown': {
        if (!props.suggestions?.length) return
        let idx = focusIndex + 1
        if (idx >= props.suggestions?.length) idx = 0
        return setFocusIndex(idx)
      }
      case 'ArrowUp': {
        if (!props.suggestions?.length) return
        let idx = focusIndex - 1
        if (idx < 0) idx = props.suggestions?.length - 1
        return setFocusIndex(idx)
      }
      case 'Enter': {
        if (filteredSuggestions.length && focusIndex > -1) return onChooseSuggestion()
        break
      }
      default: return
    }
  }

  const onBlur = () => {
    setTimeout(() => {
      setFilteredSuggesstions([])
      setFocusIndex(-1)
    }, 150)
  }

  const onChooseSuggestion = (idx) => {
    let selectIdx = idx === undefined ? focusIndex : idx
    if (selectIdx < 0) return
    const suggestion = filteredSuggestions[selectIdx]
    if (!suggestion) return
    setFocusIndex(-1)
    setFilteredSuggesstions([])
    props.onChange({target: {name: props.name, value: suggestion}})
  }

  return (
    <CFormGroup className={props.className || ""}>
      <CInputGroup className="autocomplete">
        {props.prependInput ? props.prependInput : ""}
        <CInput
          onChange={onChangeValue}
          value={props.value || ""}
          id={`autocomplete-${props.name}`}
          name={props.name}
          onClick={showAutocomplete}
          onFocus={showAutocomplete}
          placeholder={props.placeholder}
          type="text"
          onKeyDown={keyDown}
          onBlur={onBlur}
          autoComplete={`${Math.ceil(Math.random()*10000000000)}`}
          invalid={!!props.error}
        />
        {!!filteredSuggestions.length &&
          <div className="autocomplete-items">
              {
                filteredSuggestions.map((suggestion, idx) => (
                  <div className={idx === focusIndex ? "autocomplete-active" : ""} key={idx} onClick={() => onChooseSuggestion(idx)}>
                    {suggestion}
                  </div>
                ))
              }
          </div>
        }
        {props.appendInput ? props.appendInput : ""}
        {!!props.error ? <CInvalidFeedback>{props.error}</CInvalidFeedback> : ""}
      </CInputGroup>
    </CFormGroup>
  )
}

export default TextSearch