import React, { useState, useEffect } from 'react'
import Select from 'react-select'

export default (props) => {
  const [options, setOptions] = useState([])
  useEffect(() => {
    const valueField = props.valueField || 'value'
    const textField = props.textField || 'text'
    const optionGroups = props.optionGroups
    if (Array.isArray(optionGroups)) {
      return setOptions((optionGroups).map((option) => ({
        label: option[textField],
        value: option[valueField]
      })))
    }
    if (typeof optionGroups === 'object') {
      return setOptions(Object.keys(optionGroups).map((groupKey) => ({
        label: groupKey,
        options: optionGroups[groupKey].map((option) => ({
          label: option[textField],
          value: option[valueField]
        }))
      })))
    }
  }, [props.optionGroups, props.valueField, props.textField])

  const onChangeValue = (selectedValue) => {
    return props.onChange({
      target: {
        name: props.name,
        value: selectedValue
      }
    })
  }
  return (
    <Select
      options={options}
      onChange={onChangeValue}
      value={props.value}
      className={props.className || ""}
    />
  )
}