import React, { useState } from 'react'
import {
  CInputGroup,
  CInput,
  CInvalidFeedback
} from '@coreui/react'

const UploadImage = (props) => {
  const [previewImages, setPreviewImages] = useState(props.images || [])
  const [errors, setErrors] = useState([])
  const onClickUpload = () => {
    let inputId = "upload-multi-image" + (props.name ? `-${props.name}` : "")
    document.getElementById(inputId).click()
  }

  const uploadImages = (e) => {
    if (!e.target.files || !e.target.files.length) return
    const fileLength = e.target.files.length
    let i = 0
    const errors = [`Image size must less than ${props.maxWidth}*${props.maxHeight}`]
    const images = []
    const files = []

    for (let j = 0; j < (props.numberOfImages || 1) - previewImages.length && j < fileLength; j++) {
      const img = new Image();
      const objectUrl = URL.createObjectURL(e.target.files[j]);
      img.onload = function () {
        // URL.revokeObjectURL(objectUrl);
        if ((props.maxWidth && this.width > props.maxWidth) || (props.maxHeight && this.height > props.maxHeight)) {
          errors.push(`File: ${e.target.files[j].name}`)
        } else {
          images.push(objectUrl)
          files.push(e.target.files[j])
        }
        i++
        if (i === fileLength || i === ((props.numberOfImages || 1) - previewImages.length)) {
          if (errors.length > 1) setErrors(errors)
          else setErrors([])
          setPreviewImages([...previewImages, ...images])
          if (typeof props.onUploadImages === 'function') {
            props.onUploadImages(images, files)
          }
        }
      };
      img.src = objectUrl;
    }
  }

  const onRemoveImage = (pos) => {
    setPreviewImages(previewImages.filter((_, i) => i !== pos))

    if (typeof props.onRemoveImage === 'function') {
      props.onRemoveImage(pos)
    }
  }

  return (
    [
      <div className="upload-image-container d-flex flex-wrap justify-content-around">
        {(props.images?.length ? props.images : previewImages).map((image, i) => (
          <UploadImageItem
            imageUrl={image}
            position={i}
            onRemoveImage={onRemoveImage}
            key={i}
            maxWidth={props.width}
            maxHeight={props.height}
          />
        ))}
        {Math.max(previewImages.length, props.images.length) < (props.numberOfImages || 1) &&
          <div className="flex-1 upload-item">
            <img src="https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png" alt="Upload Images" onClick={onClickUpload}/>
            <button disabled={props.disabled} type="button" className="btn-upload-image" onClick={onClickUpload}>
              {props.chooseText || "Choose Images"}
            </button>
            <input id={"upload-multi-image" + (props.name ? `-${props.name}` : "")} type="file" accept="image/*" hidden onChange={uploadImages} multiple/>
          </div>
        }
      </div>,
      [...errors.map((err, idx) => (
        <CInputGroup key={idx}>
          <CInput hidden invalid={true} />
          <CInvalidFeedback>{err}</CInvalidFeedback>
        </CInputGroup>
      ))]
    ]
  )
}

const UploadImageItem = (props) => {
  return (
    <div className="flex-1 image-item" style={{width: props.maxWidth, height: props.maxHeight}}>
      <img src={props.imageUrl} alt={`#${props.position}`} />
      <button type="button" className="btn-remove-image" onClick={() => props.onRemoveImage(props.position)}>X</button>
    </div>
  )
}

export default UploadImage