import React, { useState } from 'react'
import {
  CModal,
  CModalHeader,
  CModalBody,
  CModalFooter,
  CButton,
  CCarousel,
  CCarouselItem,
  CCarouselInner,
  CCarouselIndicators,
  CCarouselControl
} from '@coreui/react'

const UploadImage = (props) => {
  const [isModal, setIsModal] = useState(false)
  const toggleModal = () => {
    setIsModal(!isModal)
  }

  return (
    <div>
      <EditImagesModal
        toggleModal={toggleModal}
        onShowModal={isModal}
        onUploadImages={props.onUploadImages}
        onRemoveImage={props.onRemoveImage}
        images={props.images}
      />
      {props.images.length
        ? <CCarousel
            arrows
            indicators
            animate
            height="250px"
          >
          <CCarouselIndicators/>
          <CCarouselInner>
            {props.images.map((image, idx) => (
              <CCarouselItem
                key={idx}
              >
                <img className="d-block" style={{width: '200px'}} src={image} alt={idx}/>
              </CCarouselItem>
            ))}
          </CCarouselInner>
          <CCarouselControl direction="prev"/>
          <CCarouselControl direction="next"/>
        </CCarousel>
        : <CButton
            onClick={toggleModal}
            color="success"
            style={{ position: "relative", top: '-5px', left: 'calc(100% - 190px)' }}
          >
            {props.images.length ? 'Edit Images' : 'Upload Images'}
          </CButton>
      }
    </div>
  )
}

const UploadImageItem = (props) => {
  return (
    <div className="flex-1 image-item">
      <img src={props.imageUrl} alt={`#${props.position}`} />
      <button type="button" className="btn-remove-image" onClick={() => props.onRemoveImage(props.position)}>X</button>
    </div>
  )
}

const EditImagesModal = (props) => {
  const [previewImages, setPreviewImages] = useState(props.images || [])

  const onClickUpload = () => {
    document.getElementById('upload-multi-image').click()
  }

  const uploadImages = (e) => {
    if (!e.target.files || !e.target.files.length) return
    let images = [...e.target.files].map((file) => URL.createObjectURL(file))

    setPreviewImages([...previewImages, ...images])
    if (typeof props.onUploadImages === 'function') {
      props.onUploadImages(images, e.target.files)
    }
  }

  const onRemoveImage = (pos) => {
    setPreviewImages(previewImages.filter((_, i) => i !== pos))

    if (typeof props.onRemoveImage === 'function') {
      props.onRemoveImage(pos)
    }
  }

  return (
    <CModal
      show={props.onShowModal}
      onClose={props.toggleModal}
      size="lg"
    >
      <CModalHeader closeButton>
        <h3>Edit Images</h3>
      </CModalHeader>
      <CModalBody>
        <div className="upload-image-container d-flex flex-wrap justify-content-around">
          {(props.images?.length ? props.images : previewImages).map((image, i) => (
            <UploadImageItem imageUrl={image} position={i} onRemoveImage={onRemoveImage} key={i}/>
          ))}
          <div className="flex-1 upload-item">
            <img src="https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png" alt="Upload Images" onClick={onClickUpload}/>
            <button type="button" className="btn-upload-image" onClick={onClickUpload}>Choose Images</button>
            <input id="upload-multi-image" type="file" accept="image/*" hidden onChange={uploadImages} multiple/>
          </div>
        </div>
      </CModalBody>
      <CModalFooter>
        <CButton
          type="button"
          color="secondary"
          onClick={props.toggleModal}
        >Close</CButton>
      </CModalFooter>
    </CModal>
  )
}

export default UploadImage