import React, { useEffect, useState } from 'react'
import Multiselect from 'react-multi-select-component'

const MultipleSelectDropdown = (props) => {
  const [options, setOptions] = useState([])
  const [values, setValues] = useState([])
  useEffect(() => {
    const { valueKey = 'value', textKey = 'label', selectedValueKey, options, values } = props
    if (!options?.length) return

    let genOptions = genMultiOptions(valueKey, textKey, selectedValueKey || textKey, options)
    setOptions(genOptions)
    const genValues = values.map((value) => genOptions.find(op => op.value === value)).filter(value => !!value)
    setValues(genValues)
  }, [props, props.options, props.values])

  const customValueRenderer = (selected) => {
    return selected.length
      ? selected.map(({ selectedValues }) => selectedValues).join(', ')
      : "Select...";
  }

  const genMultiOptions = (vKey, tKey, selectedValueKey, options) => {
    return options.map((option) => ({
      label: option[tKey],
      value: option[vKey],
      selectedValues: option[selectedValueKey]
    }))
  }

  const onChange = (choosenValues) => {
    if (typeof props.onSelect === 'function') {
      return props.onSelect(choosenValues.map(v => v.value))
    }
    setValues(choosenValues)
  }

  const onRemove = () => {
    if (typeof props.onRemove === 'function') {
      return props.onRemove()
    }
    setValues([])
  }

  const genAllItemsAreSelected = () => Object.values(options).map(p => p.label).join(', ')

  return (
    <Multiselect
      disabled={props.disabled}
      className="multiple-select"
      options={options} // Options to display in the dropdown
      hasSelectAll={false}
      value={values} // Preselected value to persist in dropdown
      // onSelect={this.onSelect} // Function will trigger on select event
      onRemove={onRemove} // Function will trigger on remove event
      onChange={onChange}
      displayValue="" // Property name to display in the dropdown options
      overrideStrings={{
        allItemsAreSelected: genAllItemsAreSelected(),
      }}
      valueRenderer={customValueRenderer}
    />
  )
}

export default MultipleSelectDropdown