import React, { useEffect, useState } from 'react'
import { useSelector, useDispatch } from 'react-redux'
import {
  CCreateElement,
  CSidebar,
  CSidebarBrand,
  CSidebarNav,
  CSidebarNavDivider,
  CSidebarNavTitle,
  CSidebarMinimizer,
  CSidebarNavDropdown,
  CSidebarNavItem,
} from '@coreui/react'

// sidebar nav config
import navigation from './_nav'

const TheSidebar = ({ panels }) => {
  const [navs, setNavs] = useState([])
  const dispatch = useDispatch()
  const show = useSelector(state => state.sidebarShow)
  useEffect(() => {
    const filterNavigations = (panels) => {
      return navigation.filter((nav) => {

        return nav.alwayshow || (nav.models || []).some(model => panels[model])
      })
    }
    const filtedNavs = filterNavigations(panels)
    setNavs(filtedNavs)
  }, [panels])

  return (
    <CSidebar
      show={show}
      onShowChange={(val) => dispatch({type: 'set', sidebarShow: val })}
    >
      <CSidebarBrand className="d-md-down-none" to="/">
        <h3>Digital Content</h3>
      </CSidebarBrand>
      <CSidebarNav>

        <CCreateElement
          items={navs}
          components={{
            CSidebarNavDivider,
            CSidebarNavDropdown,
            CSidebarNavItem,
            CSidebarNavTitle
          }}
        />
      </CSidebarNav>
      <CSidebarMinimizer className="c-d-md-down-none"/>
    </CSidebar>
  )
}

export default React.memo(TheSidebar)
