import React, { useEffect, useState } from 'react'
import {
  CModal,
  CModalHeader,
  CModalBody,
  CModalFooter,
  CButton,
  CDataTable
} from '@coreui/react'
import moment from 'moment'

const MediaListModal = (props) => {
  const [selectedMedia, setSelectedMedia] = useState([])
  const [mediaList, setMediaList] = useState([])
  const { search } = props
  useEffect(() => {
    search()
  }, [])

  useEffect(() => {
    setMediaList(props.mediaList)
  }, [props.mediaList])

  const onAddMedia = () => {
    props.addMedia(selectedMedia)
    setSelectedMedia([])
  }

  const onToggleSelected = (media) => {
    media.selected = !media.selected

    setMediaList(mediaList.map((m) => {
      if (m.id !== media.id) return m
      m.selected = media.selected
      return m
    }))
    if (media.selected) setSelectedMedia([...selectedMedia, media])
    else setSelectedMedia([selectedMedia.filter(m => m.id !== media.id)])
  }

  return (
    <CModal
      show={props.onShowModal}
      onClose={props.toggleModal}
      size="lg"
    >
      <CModalHeader>
        <h3>Select Media</h3>
      </CModalHeader>
      <CModalBody>
        <Table
          mediaList={mediaList}
          onToggleSelected={onToggleSelected}
        />
      </CModalBody>
      <CModalFooter>
        <CButton type="button" color="success" onClick={onAddMedia}>Add</CButton>{' '}
        <CButton
          type="button"
          color="secondary"
          onClick={props.toggleModal}
        >Cancel</CButton>
      </CModalFooter>
    </CModal>
  )
}

const Table = (props) => {
  const fields = [
    { key: 'select', _style: { width: '10%'} },
    { key: 'name', _style: { width: '30%'} },
    { key: 'artists', _style: { width: '30%'} },
    { key: 'upload date', _style: { width: '30%'} },
  ]

  const selectMedia = (media) => {
    props.onToggleSelected(media)
  }

  return (
    <CDataTable
      items={props.mediaList}
      fields={fields}
      tableFilter
      hover
      onRowClick={selectMedia}
      clickableRows
      scopedSlots = {{
        'select':
          (item)=>(
            <td className="text-center">
              <input type="checkbox" checked={item.selected} onChange={() => {}} />
            </td>
          ),
        'artists':
          (item)=>(
            <td className="">
              {item.artists.join(' - ')}
            </td>
          ),
        // 'authors':
        //   (item)=>(
        //     <td className="">
        //       {item.artists.join(' - ')}
        //     </td>
        //   ),
        'upload date':
          (item)=>(
            <td style={{verticalAlign: "middle"}}>
              {moment(item.created_at).format('DD-MM-YYYY hh:mm:ss')}
            </td>
          ),
      }}
    />
  )
}

export default MediaListModal