import React, { useEffect, useState } from 'react'
import {
  CCard,
  CCardBody,
  CCardHeader,
  CCol,
  CDataTable,
  CRow,
  CDropdownToggle,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CButton
} from '@coreui/react'
import moment from 'moment'

import { mediaApi } from '../../../api'
import MediaListModal from './MediaListModal'

const fields = ['name', 'artists', 'upload date', 'action']

const Tables = (props) => {
  const [addMediaTableShow, setAddMediaTableShow] = useState(false)
  const [filterMediaList, setFilterMediaList] = useState([])
  const [error, setError] = useState('')

  useEffect(() => {
    if (!addMediaTableShow) return

    fetchMedia()
  }, [addMediaTableShow])

  const fetchMedia = async (filter) => {
    let res = await mediaApi.getListForSelect(filter)
    if (!res.isError) {
      let media = res.data.media
      media.forEach((medium) => {
        medium.artists = medium.artists.map(a => a.name)
        medium.authors = medium.authors.map(a => a.name)
        medium.composers = medium.composers.map(a => a.name)
      })
      return setFilterMediaList(media)
    }
    setError(res.errorMessage)
  }

  const searchMedia = (filter) => {
    filter = filter || {}
    // setFilter(filter)
    fetchMedia(filter)
  }

  const addMedia = (media) => {
    props.addMedia(media)
    toggleAddMediaModal()
  }

  const toggleAddMediaModal = () => {
    setAddMediaTableShow(!addMediaTableShow)
  }

  return (
    <CRow>
      <MediaListModal
        addMedia={addMedia}
        mediaList={filterMediaList}
        toggleModal={toggleAddMediaModal}
        onShowModal={addMediaTableShow}
        error={error}
        search={searchMedia}
      />
      <CCol style={{ paddingLeft: '0px', paddingRight: '0px' }}>
        <CCard>
          <CCardHeader>
            <h3 style={{ display: 'inline-block' }}>Song List</h3>
            <CButton
              type="button"
              onClick={toggleAddMediaModal}
              disabled={props.disabled}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(100% - 190px)' }}
            >
              Add Songs
            </CButton>
          </CCardHeader>
          <CCardBody>
          {
            <CDataTable
              items={props.songs}
              fields={fields}
              dark
              hover
              striped
              // bordered
              size="sm"
              itemsPerPage={10}
              pagination
              scopedSlots = {{
                'artists':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.artists?.join(' - ')}
                    </td>
                  ),
                // 'authors':
                //   (item)=>(
                //     <td style={{verticalAlign: "middle"}}>
                //       {item.authors?.join(' - ')}
                //     </td>
                //   ),
                'name':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.name}
                    </td>
                  ),
                'upload date':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {moment(item.created_at).format('DD-MM-YYYY hh:mm:ss')}
                    </td>
                  ),
                'action': (item, idx) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CDropdown className="m-1 btn-group">
                      <CDropdownToggle color="secondary">
                        Actions
                      </CDropdownToggle>
                      <CDropdownMenu>
                        <CDropdownItem disabled={props.disabled} onClick={() => props.removeMedium(idx)} className="remove">Remove</CDropdownItem>
                      </CDropdownMenu>
                    </CDropdown>
                  </td>
                )
              }}
            />
          }
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default Tables