import React, { useState, useEffect } from 'react'
import { useLocation } from 'react-router-dom'
import {
  CSpinner
} from '@coreui/react'
import AlbumList from './list/List'
import { albumsApi, artistsApi } from '../../api'

const AlbumManagement = (props) => {
  const [isLoading, setLoading] = useState(false)
  const [albums, setAlbums] = useState([])
  const [sugArtists, setSugArtists] = useState([])
  const limit = 10
  const [filter, setFilter] = useState({})
  const queryPage = useLocation().search.match(/page=([0-9]+)/, '')
  const [count, setCount] = useState(10)
  const currentPage = Number(queryPage && queryPage[1] ? queryPage[1] : 1)
  const [page, setPage] = useState(currentPage || 1)

  const pageChange = newPage => {
    if ((newPage || 1) === page) return
    fetchAlbums({}, newPage)
  }

  useEffect(() => {
    const fetchSugArtists = async () => {
      let suggestedArtists = await artistsApi.fetchArtistsForSuggesstions()
      setSugArtists(suggestedArtists)
    }
    fetchAlbums({}, currentPage, true)
    fetchSugArtists()
  }, [])

  const fetchAlbums = async (filter, page, fetchCount) => {
    setLoading(true)
    let res = await albumsApi.getList({...filter, limit, page, fetchCount})
    setLoading(false)
    if (!res.isError) {
      setPage(page)
      let {albums, count} = res.data
      setAlbums(albums.map((m) => {
        let images = m.images?.map(f => f?.thumbnailPath || f?.filePath)
        m.images = images
        m.artists = m.artists?.map(a => a.name)
        m.authors = m.authors?.map(a => a.name)
        m.composers = m.composers?.map(a => a.name)
        return m
      }))
      if (fetchCount) setCount(count)
    }
  }

  const onEdit = (id) => {
    props.history.push('/albums/'+id)
  }
  const editStatus = async (id, status) => {
    let update = {
      status: status === 'active' ? status : 'inactive'
    }
    setLoading(true)
    let res = await albumsApi.editStatus(id, update.status)
    setLoading(false)
    if (!res.isError) {
      setAlbums(albums.map((p) => {
        if (p.id === id) p.status = status
        return p
      }))
    }
  }
  const onRemove = async (id) => {
    return editStatus(id, 'removed')
  }
  const onDeactive = async (id) => {
    return editStatus(id, 'inactive')
  }
  const onActive = async (id) => {
    return editStatus(id, 'active')
  }

  const onSearch = (fieldName, value) => {
    let newFilter = {...filter, [fieldName]: value}
    setFilter(newFilter)

    fetchAlbums(newFilter, 1, true)
  }

  return (
    [ <div className={"justify-content-center align-items-center custom-spinner custom-spinner-" + (isLoading ? "loading" : "stop")}>
        <CSpinner color="success" size="lg" style={{width: '4rem', height: '4rem'}}/>
      </div>,
      <AlbumList
        {...props}
        albums={albums}
        onEdit={onEdit}
        onActive={onActive}
        onDeactive={onDeactive}
        onRemove={onRemove}
        page={page}
        pages={Math.ceil(count / limit)}
        limit={limit}
        pageChange={pageChange}
        search={onSearch}
        sugArtists={sugArtists}
      />
    ]
  )
}

export default AlbumManagement