import React from 'react'
import {
  CBadge,
  CCard,
  CCardBody,
  CCardHeader,
  CCol,
  CDataTable,
  CRow,
  CDropdownToggle,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CDropdownDivider,
  CCarousel,
  CCarouselInner,
  CCarouselItem,
  CButton,
  CPagination
} from '@coreui/react'
import Search from '../../../containers/Search'

const getBadge = status => {
  switch (status) {
    case 'active': return 'success'
    case 'inactive': return 'secondary'
    case 'pending': return 'warning'
    case 'removed': return 'danger'
    default: return 'primary'
  }
}
const fields = ['id', 'image', 'name', 'artists', 'views', 'status', 'action']

const Tables = (props) => {
  const onRegister = () => {
    props.history.push('/albums/new')
  }

  return (
    <CRow>
      <CCol>
        <CCard>
          <CCardHeader align="center">
            <h1 style={{ display: 'inline-block' }}>Album List</h1>
            <CButton
              onClick={onRegister}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(50% - 152px)' }}
            >
              Create Album
            </CButton>
          </CCardHeader>
          <CCardBody>
            <Search
              items={[{
                name: "status",
                type: "select",
                placeholder: "Status",
                options: [{
                  value: 'active',
                  text: 'Active',
                },{
                  value: 'inactive',
                  text: 'Inactive',
                }]
              }, {
                name: "name",
                type: "text",
                placeholder: "Media Name...",
              }, {
                name: "artistName",
                type: "text",
                placeholder: "Artist Name...",
                gridSize: 2,
                autocomplete: true,
                suggestions: props.sugArtists
              }, {
                name: "contractDate",
                type: "dateRange",
                placeholder: "Contract Date",
                field: "Contract",
                gridSize: 3
              }, {
                name: "createdAt",
                type: "dateRange",
                placeholder: "Upload Date",
                field: "Upload",
                gridSize: 3
              }]}
              search={props.search}
            />
            <CDataTable
              items={props.albums}
              fields={fields}
              dark
              hover
              striped
              // bordered
              size="sm"
              itemsPerPage={props.limit}
              activePage={props.page}
              pagination
              scopedSlots = {{
                'id':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.id}
                    </td>
                  ),
                'name':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.name}
                    </td>
                  ),
                'artists':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.mainArtist?.fullName || item.mainArtist?.name || item.mainArtist?.fullName || item.artists[0]?.name || 'Unknown'}
                    </td>
                  ),
                'image': (item) => (
                  <td >
                    <CCarousel activeIndex={0}>
                      <CCarouselInner>
                        <CCarouselItem style={{ width: '100px' }}>
                          <img
                            className="d-block img-fluid"
                            src={item.images[0] || "https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png"}
                            alt={`slide #1`}
                          />
                        </CCarouselItem>
                      </CCarouselInner>
                    </CCarousel>
                  </td>
                ),
                'views':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.views?.reduce((v, a) => v + a.count, 0) || 0}
                    </td>
                  ),
                'status':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      <CDropdown className="m-1 btn-group" style={{width: '100px'}}>
                        <CDropdownToggle color={getBadge(item.status)}>
                            {item.status}
                        </CDropdownToggle>
                        <CDropdownMenu>
                          <CDropdownItem onClick={() => props.onActive(item.id)} className="success">Active</CDropdownItem>
                          <CDropdownItem onClick={() => props.onDeactive(item.id)} className="remove">Deactive</CDropdownItem>
                        </CDropdownMenu>
                      </CDropdown>
                    </td>
                  ),
                'action': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CButton color="secondary" style={{width: '100px'}} onClick={() => props.onEdit(item.id)}>Edit</CButton>
                  </td>
                )
              }}
            />
            <CPagination
              activePage={props.page}
              onActivePageChange={props.pageChange}
              pages={props.pages}
              doubleArrows={false}
              align="center"
            />
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default Tables