import React from 'react'
import {
  CBadge,
  CCard,
  CCardBody,
  CCardHeader,
  CCol,
  CDataTable,
  CRow,
  CDropdownToggle,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CDropdownDivider,
  CCarousel,
  CCarouselInner,
  CCarouselItem,
  CButton,
  CPagination
} from '@coreui/react'
import Search from '../../../containers/Search'


const getBadge = status => {
  switch (status) {
    case 'active': return 'success'
    case 'inactive': return 'secondary'
    case 'pending': return 'warning'
    case 'removed': return 'danger'
    default: return 'primary'
  }
}
const fields = ['id', 'image', 'name', 'professions', 'status', 'action']

const Tables = (props) => {
  const onRegister = () => {
    props.history.push('/artists/new')
  }

  return (
    <CRow>
      <CCol>
        <CCard>
          <CCardHeader align="center">
            <h1 style={{ display: 'inline-block' }}>Artist List</h1>
            <CButton
              onClick={onRegister}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(50% - 152px)' }}
            >
              Register New
            </CButton>
          </CCardHeader>
          <CCardBody>
            <Search
              items={[{
                name: "status",
                type: "select",
                placeholder: "Status",
                options: [{
                  value: 'active',
                  text: 'Active',
                },{
                  value: 'inactive',
                  text: 'Inactive',
                }],
                gridSize: 2
              }, {
                name: "role",
                type: "select",
                placeholder: "Role",
                options: [{
                  value: 'Artist',
                  text: 'Artist',
                },{
                  value: 'Composer',
                  text: 'Composer',
                },{
                  value: 'Author',
                  text: 'Author',
                }],
                gridSize: 2
              }, {
                name: "name",
                type: "text",
                placeholder: "Artist Name...",
                gridSize: 4,
                autocomplete: true,
                suggestions: props.sugArtists
              }]}
              search={props.search}
            />
            <CDataTable
              items={props.artists}
              fields={fields}
              dark
              hover
              striped
              // bordered
              size="sm"
              pagination
              itemsPerPage={props.limit}
              activePage={props.page}
              scopedSlots = {{
                'id':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.id}
                    </td>
                  ),
                'name':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.name}
                    </td>
                  ),
                'professions':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.professions.join(', ')}
                    </td>
                  ),
                'image': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CCarousel activeIndex={0}>
                      <CCarouselInner>
                        <CCarouselItem style={{ width: '100px' }}>
                          <img className="d-block img-fluid" src={item.image} alt="slide 1" />
                        </CCarouselItem>
                      </CCarouselInner>
                    </CCarousel>
                  </td>
                ),
                'status':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      <CDropdown className="m-1 btn-group" style={{width: '100px'}}>
                        <CDropdownToggle color={getBadge(item.status)}>
                            {item.status}
                        </CDropdownToggle>
                        <CDropdownMenu>
                          <CDropdownItem onClick={() => props.onActive(item.id)} className="success">Active</CDropdownItem>
                          <CDropdownItem onClick={() => props.onDeactive(item.id)} className="remove">Deactive</CDropdownItem>
                        </CDropdownMenu>
                      </CDropdown>
                    </td>
                  ),
                'action': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CButton color="secondary" style={{width: '100px'}} onClick={() => props.onEdit(item.id)}>Edit</CButton>
                  </td>
                )
              }}
            />
            <CPagination
              activePage={props.page}
              onActivePageChange={props.pageChange}
              pages={props.pages}
              doubleArrows={false}
              align="center"
            />
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default Tables