import React, { useState, useEffect } from 'react'
import { CChartLine } from '@coreui/react-chartjs'
import { getStyle, hexToRgba } from '@coreui/utils'
import { dashboardApi } from '../../api'

const brandSuccess = getStyle('success') || '#4dbd74'
const brandInfo = getStyle('info') || '#20a8d8'
const brandDanger = getStyle('danger') || '#f86c6b'
const colors = [brandSuccess, brandInfo, brandDanger]


const MainChartExample = attributes => {
  const defaultOptions = (()=>{
    return {
        maintainAspectRatio: false,
        legend: {
          display: false
        },
        scales: {
          xAxes: [{
            gridLines: {
              drawOnChartArea: false
            }
          }],
          yAxes: [{
            // ticks: {
            //   beginAtZero: true,
            //   maxTicksLimit: 5,
            //   stepSize: Math.ceil(250 / 5),
            //   max: 250
            // },
            gridLines: {
              display: true
            }
          }]
        },
        elements: {
          point: {
            radius: 0,
            hitRadius: 10,
            hoverRadius: 4,
            hoverBorderWidth: 3
          }
        }
      }
    }
  )()

  const [datasets, setDatasets] = useState([])
  const [options, setOptions] = useState(defaultOptions)
  const [labels, setLabels] = useState(new Array(7).fill('2021-04-04'))

  useEffect(() => {
    const fetchStatistics = async () => {
      const res = await dashboardApi.getViewCharts()
      if (!res.isError) {
        setDatasets(Object.keys(res.data.charts).map((model, idx) => ({
          label: model,
          borderColor: colors[idx % colors.length],
          pointHoverBackgroundColor: colors[idx % colors.length],
          borderWidth: 2,
          data: res.data.charts[model]
        })))
        setLabels(res.data.keys)
      }
    }

    fetchStatistics()
  }, [])

  // render
  return (
    <CChartLine
      {...attributes}
      datasets={datasets}
      options={options}
      labels={labels}
    />
  )
}


export default MainChartExample
