import React, { useState, useEffect } from 'react'
import { useLocation } from 'react-router-dom'
import {
  CSpinner
} from '@coreui/react'
import ContractsList from './list/List'
import { contractsApi } from '../../api'

const ContractsManagement = (props) => {
  const [isLoading, setLoading] = useState(false)
  const limit = 5
  const [contracts, setContracts] = useState([])
  const queryPage = useLocation().search.match(/page=([0-9]+)/, '')
  const [count, setCount] = useState(10)
  const [filter, setFilter] = useState({
    name: "",
    id: "",
    contractDate: {
      startDate: null,
      endDate: null
    },
  })
  const currentPage = Number(queryPage && queryPage[1] ? queryPage[1] : 1)
  const [page, setPage] = useState(currentPage || 1)

  const pageChange = newPage => {
    if ((newPage || 1) === page) return
    fetchContracts(filter, newPage)
  }

  useEffect(() => {
    fetchContracts({}, currentPage, true)
  }, [])

  const onSearch = (fieldName, value) => {
    let newFilter = {...filter, [fieldName]: value}
    setFilter(newFilter)

    fetchContracts(newFilter, 1, true)
  }

  const fetchContracts = async (filter, page, fetchCount) => {
    setLoading(true)
    let res = await contractsApi.getList({...filter, limit, page, fetchCount})
    setLoading(false)
    if (!res.isError) {
      setPage(page)
      let {contracts, count} = res.data
      setContracts(contracts.map((m) => {
        let images = m.images?.map(f => f?.thumbnailPath || f?.filePath)
        delete m.images
        m.images = images
        return m
      }))
      if (fetchCount) setCount(count)
    }
  }

  const onEdit = (id) => {
    props.history.push('/contracts/'+id)
  }

  const onDownload = (filePath) => {
    let link = document.createElement("a")
    // If you don't know the name or want to use
    // the webserver default set name = ''
    let fileName = filePath.split('/').reverse()[0].split('?')[0]
    link.setAttribute('download', fileName)
    link.setAttribute('target', '_blank')
    link.href = filePath
    document.body.appendChild(link)
    link.click()
    link.remove()
  }
  const editStatus = async (id, status) => {
    let update = {
      status: status === 'active' ? status : 'inactive'
    }
    setLoading(true)
    let res = await contractsApi.editStatus(id, update.status)
    setLoading(false)
    if (!res.isError) {
      setContracts(contracts.map((p) => {
        if (p.id === id) p.status = status
        return p
      }))
    }
  }

  const onRemove = async (id) => {
    return editStatus(id, 'removed')
  }
  const onDeactive = async (id) => {
    return editStatus(id, 'inactive')
  }
  const onActive = async (id) => {
    return editStatus(id, 'active')
  }

  return (
    [<div className={"justify-content-center align-items-center custom-spinner custom-spinner-" + (isLoading ? "loading" : "stop")}>
      <CSpinner color="success" size="lg" style={{width: '4rem', height: '4rem'}}/>
    </div>,
    <ContractsList
      {...props}
      contracts={contracts}
      onDownload={onDownload}
      onEdit={onEdit}
      onActive={onActive}
      onDeactive={onDeactive}
      onRemove={onRemove}
      page={page}
      pages={Math.ceil(count / limit)}
      limit={limit}
      pageChange={pageChange}
      search={onSearch}
    />]
  )
}

export default ContractsManagement;