import React from 'react'
import {
  CCard,
  CCardBody,
  CCardHeader,
  CCol,
  CDataTable,
  CRow,
  CDropdownToggle,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CCarousel,
  CCarouselInner,
  CCarouselItem,
  CButton,
  CPagination
} from '@coreui/react'
import Search from '../../../containers/Search'

const getBadge = status => {
  switch (status) {
    case 'active': return 'success'
    case 'inactive': return 'secondary'
    case 'pending': return 'warning'
    case 'removed': return 'danger'
    default: return 'primary'
  }
}
const fields = ['id', 'name', 'provider', 'status', 'view PDF', 'action']

const Tables = (props) => {
  const onRegister = () => {
    props.history.push('/contracts/new')
  }
  const onSearch = (name, value) => {
    props.search(name, value)
  }

  return (
    <CRow>
      <CCol>
        <CCard>
          <CCardHeader align="center">
            <h1 style={{ display: 'inline-block' }}>Contract List</h1>
            <CButton
              onClick={onRegister}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(50% - 152px)' }}
            >
              Create
            </CButton>
          </CCardHeader>
          <CCardBody>
            <Search
              items={[{
                name: "status",
                type: "select",
                placeholder: "Status",
                options: [{
                  value: 'active',
                  text: 'Active',
                },{
                  value: 'inactive',
                  text: 'Inactive',
                }],
              }, {
                name: "id",
                type: "text",
                placeholder: "Contracts ID...",
              }, {
                name: "name",
                type: "text",
                placeholder: "Contracts Name...",
              },  {
                name: "contractDate",
                type: "dateRange",
                placeholder: "Contract Date",
                field: 'Contract',
                gridSize: 3
              }]}
              search={onSearch}
            />
            <CDataTable
              items={props.contracts}
              fields={fields}
              dark
              hover
              striped
              // bordered
              size="sm"
              itemsPerPage={props.limit}
              activePage={props.page}
              pagination
              scopedSlots = {{
                'id':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.id}
                    </td>
                  ),
                'image': (item) => (
                  <td >
                    <CCarousel activeIndex={0}>
                      <CCarouselInner>
                        <CCarouselItem style={{ width: '100px' }}>
                          <img
                            className="d-block img-fluid"
                            src={item.images[0] || "https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png"}
                            alt={`slide #1`}
                          />
                        </CCarouselItem>
                      </CCarouselInner>
                    </CCarousel>
                  </td>
                ),
                'name':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.name}
                    </td>
                  ),
                'provider':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.provider?.name || 'Unknown'}
                    </td>
                  ),
                'status':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      <CDropdown className="m-1 btn-group" style={{width: '100px'}}>
                        <CDropdownToggle color={getBadge(item.status)}>
                            {item.status}
                        </CDropdownToggle>
                        <CDropdownMenu>
                          <CDropdownItem onClick={() => props.onActive(item.id)} className="success">Active</CDropdownItem>
                          <CDropdownItem onClick={() => props.onDeactive(item.id)} className="remove">Deactive</CDropdownItem>
                        </CDropdownMenu>
                      </CDropdown>
                    </td>
                  ),
                'action': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CButton color="secondary" style={{width: '100px'}} onClick={() => props.onEdit(item.id)}>Edit</CButton>
                  </td>
                ),
                'view PDF': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    {
                      !!item.pdf?.filePath &&
                      <div>
                        <a
                          target="_blank"
                          download={item.pdf.filePath.split('/').reverse()[0].split('?')[0]}
                          href={item.pdf.filePath}
                          style={{color: "#5aea8b"}}
                        >
                          <span className="fas fa-arrow-circle-down pr-2"></span>
                          Contract File
                        </a>
                      </div>
                    }
                  </td>
                )
              }}
            />
          <CPagination
            activePage={props.page}
            onActivePageChange={props.pageChange}
            pages={props.pages}
            doubleArrows={false}
            align="center"
          />
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default Tables