import React, { useEffect, useState } from 'react'
import { useHistory } from 'react-router-dom'
import {
  CCard,
  CCardBody,
  CCardHeader,
  CFormGroup,
  CInputGroup,
  CInputGroupPrepend,
  CInputGroupText,
  CInput,
  CInputGroupAppend,
  CInvalidFeedback,
  CModal,
  CModalBody,
  CModalHeader,
  CModalFooter,
  CButton,
  CSelect,
  CForm,
  CTextarea,
  CTooltip,
} from '@coreui/react'
import { businessTypes } from '../../../constants'
import UploadMediaImages from '../details/Images'
import GroupSelect from '../../../containers/GroupSelect'
import MultipleSelectDropdown from '../../../containers/MultipleSelectDropdown'
import AutocompleteInput from '../../../containers/AutocompleteInput'

const MediaForm = (props) => {
  const { medium } = props
  const [newMedium, setNewMedium] = useState({})
  const [covers, setCovers] = useState([])
  const [banners, setBanners] = useState([])
  const [files, setFiles] = useState({
    fileFull: null,
    fileIntro: null,
    fileMv: null,
    fileBeat: null,
    covers: [],
    banners: []
  })
  const [errors, setErrors] = useState({})

  useEffect(() => {
    const covers = medium?.images?.map(f => URL.createObjectURL(f)) || []
    const banners = medium?.banner ? [URL.createObjectURL(medium.banner)] : []
    const fileFullName = medium.fileFull?.name
    const fileIntroName = medium.fileIntro?.name
    const fileBeatName = medium.fileBeat?.name
    const fileMvName = medium.fileMv?.name
    debugger
    setNewMedium({
      ...medium,
      fileFull: fileFullName,
      fileIntro: fileIntroName,
      fileBeat: fileBeatName,
      fileMv: fileMvName,
    })
    setCovers(covers)
    setBanners(banners)
    setFiles({
      covers: medium.images || [],
      banners: medium.banner ? [medium.banner] : [],
      fileFull: medium.fileFull,
      fileIntro: medium.fileIntro,
      fileBeat: medium.fileBeat,
      fileMv: medium.fileMv,
    })
  }, [medium?.id])
  useEffect(() => {
    setErrors(props.errors)
  }, [props.errors])

  const onChangeValue = ({target: { name, value }}) => {
    setErrors({...errors, [name]: '', general: ''})
    const updateMedium = {
      [name]: value
    }
    if (name === 'contractId') {
      value = value.value
      let selectedContract = props.contracts.find(c => c.id === value)
      const contractStart = selectedContract?.startDate?.slice(0, 10)
      const contractEnd = selectedContract?.endDate?.slice(0, 10)
      updateMedium.contractStartDate = contractStart
      updateMedium.contractEndDate = contractEnd
    }
    setNewMedium({...newMedium, ...updateMedium})
  }

  const onSelectArtist = (name,  values ) => {
    setNewMedium({...newMedium, [name]: values})
  }

  const openUpload = (id) => {
    document.getElementById(id).click()
  }

  const uploadFile = ({ target: { name, files: inputFiles }}) => {
    if (inputFiles && inputFiles[0]) {
      const size = inputFiles[0].size
      let sizeConfigKey  = `${name}MaxSize`
      const isOverSize = props.configs[sizeConfigKey] ? size > props.configs[sizeConfigKey] * 1024 * 1024 : false
      if (isOverSize) {
        return setErrors({
          ...errors,
          [name]: `File size is over ${props.configs[sizeConfigKey]} MB`
        })
      }
      setErrors({...errors, [name]: ""})
      setNewMedium({...newMedium, [name]: inputFiles[0].name})
      setFiles({...files, [name]: inputFiles[0]})
    }
  }

  const onUploadImages = (type, imageUrls, inputFiles) => {
    if (type === 'covers') setCovers([...covers, ...imageUrls])
    else setBanners([...banners, ...imageUrls])
    setFiles({...files, [type]: [...files[type], ...inputFiles]})
  }

  const onRemoveImage = (type, pos) => {
    if (type === 'covers') setCovers(covers.filter((_, i) => i !== pos))
    else setBanners(banners.filter((_, i) => i !== pos))
    setFiles({...files, [type]: files[type].filter((_, i) => i !== pos)})
  }

  const removeFile = (e, fileField) => {
    e.stopPropagation()
    setFiles({
      ...files,
      [fileField]: null
    })
    setNewMedium({
      ...newMedium,
      [fileField]: ""
    })
    document.getElementById(fileField).value = null
  }

  const generateRelationFiles = (media, files) => {
    const submitMedia = {
      ...media,
      fileFull: files.fileFull,
      fileIntro: files.fileIntro,
      fileBeat: files.fileBeat,
      fileMv: files.fileMv,
    }
    if (files.banners?.length > 0) submitMedia.banner = files.banners[0]
    submitMedia.images = files.covers
    return submitMedia
  }

  const onSave = async () => {
    let validateErrors = {};
    if (!newMedium.name) {
      validateErrors['name'] = 'Media name is required!';
    }
    if (newMedium.genreCategory) {
      const genre = props.genres.find(g => g.categoryCodePath.trim() === newMedium.genreCategory.trim())
      if (!genre) {
        validateErrors['genreCategory'] = 'Please select genre in dropdown!'
      }
    }
    if (newMedium.artistName) {
      const artist = props.artists?.find(a => a.name.trim() === newMedium.artistName.trim())
      if (!artist) {
        validateErrors['artistName'] = 'Please select main artist in dropdown!'
      }
    }
    if (newMedium.authorName) {
      const artist = props.artists?.find(a => a.name.trim() === newMedium.authorName.trim())
      if (!artist) {
        validateErrors['authorName'] = 'Please select author in dropdown!'
      }
    }
    if (newMedium.composerName) {
      const artist = props.artists?.find(a => a.name.trim() === newMedium.composerName.trim())
      if (!artist) {
        validateErrors['composerName'] = 'Please select author in dropdown!'
      }
    }
    if (newMedium.contractId?.value) {
      const contract = props.contracts?.find(a => a.id === newMedium.contractId?.value.trim())
      if (!contract) {
        validateErrors['contractId'] = 'Please select a contract in suggestion list!'
      }
    } else {
      delete newMedium.contractId
    }
    if (Object.values(validateErrors).length) return setErrors(validateErrors)

    const medium = generateRelationFiles(newMedium, files)

    props.save(medium)
  }

  return (
    <CModal
      show={props.isShow}
      onClose={props.cancel}
      size="xl"
    >
      <CModalHeader>
        <h3>Edit Medium #{newMedium.id}</h3>
      </CModalHeader>
      <CModalBody>
        <CForm className="form-horizontal" formAction="">
          <CCard className="mb-2">
            <CCardBody className="row justify-content-center">
              <div className="col-5">
                <UploadMediaImages
                  covers={covers}
                  banners={banners}
                  onUploadCovers={(...args) => onUploadImages('covers', ...args)}
                  onRemoveCover={(...args) => onRemoveImage('covers', ...args)}
                  onUploadBanners={(...args) => onUploadImages('banners', ...args)}
                  onRemoveBanner={(...args) => onRemoveImage('banners', ...args)}
                  configs={props.configs}
                />
              </div>
              <div className="col-7">
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Media Name</CInputGroupText>
                    </CInputGroupPrepend>
                    <CInput
                      onChange={onChangeValue}
                      defaultValue={newMedium ? newMedium.name : ''} type="text"
                      id="name"
                      name="name"
                      invalid={!!errors["name"]}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["name"] ? <CInvalidFeedback>{errors["name"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Provider</CInputGroupText>
                    </CInputGroupPrepend>
                      <CSelect
                        onChange={onChangeValue}
                        value={newMedium ? newMedium.providerId : ''}
                        type="text"
                        id="providerId"
                        name="providerId"
                        invalid={!!errors["providerId"]}
                      >
                        <option value="">Select Provider</option>
                        {props.providers.map((provider) => (
                          <option value={provider.id}>{provider.name}</option>
                        ))}
                      </CSelect>
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["providerName"] ? <CInvalidFeedback>{errors["providerName"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <AutocompleteInput
                  className="col-12 row"
                  prependInput={
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Genres</CInputGroupText>
                    </CInputGroupPrepend>
                  }
                  appendInput={
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  }
                  error={errors["genreCategory"]}
                  name="genreCategory"
                  onChange={onChangeValue}
                  suggestions={props.genres.map(g => g.categoryCodePath)}
                  value={newMedium.genreCategory}
                />
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Type</CInputGroupText>
                    </CInputGroupPrepend>
                      <CSelect
                        onChange={onChangeValue}
                        value={newMedium ? newMedium.type : ''}
                        type="text"
                        id="type"
                        name="type"
                        invalid={!!errors["type"]}
                      >
                        <option value="">Select Type</option>
                        {businessTypes.map((type) => (
                          <option value={type.value}>{type.name}</option>
                        ))}
                      </CSelect>
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["type"] ? <CInvalidFeedback>{errors["type"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Initiator</CInputGroupText>
                    </CInputGroupPrepend>
                    <CInput
                      value={newMedium ? newMedium.initiatorName : ''}
                      type="text"
                      id="initiator"
                      readOnly
                      className="no-icon"
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-contract" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Contract Number</CInputGroupText>
                    </CInputGroupPrepend>
                    <GroupSelect
                      className="multiple-select"
                      name="contractId"
                      optionGroups={props.contracts}
                      textField="id"
                      valueField="id"
                      value={newMedium.contractId}
                      onChange={onChangeValue}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-contract" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Contract Start Date</CInputGroupText>
                    </CInputGroupPrepend>
                    <CInput
                      onChange={onChangeValue}
                      defaultValue={newMedium ? newMedium.contractStartDate : ''}
                      type="text"
                      id="contractStartDate"
                      name="contractStartDate"
                      className="no-icon"
                      readOnly
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-contract" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Contract End Date</CInputGroupText>
                    </CInputGroupPrepend>
                    <CInput
                      onChange={onChangeValue}
                      defaultValue={newMedium ? newMedium.contractEndDate : ''}
                      type="text"
                      id="contractEndDate"
                      name="contractEndDate"
                      className="no-icon"
                      readOnly
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-contract" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >ISRC Code</CInputGroupText>
                    </CInputGroupPrepend>
                    <CInput
                      onChange={onChangeValue}
                      defaultValue={newMedium ? newMedium.isrc : ''} type="text"
                      id="isrc"
                      name="isrc"
                      className="no-icon"
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-hashtag" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Singers</CInputGroupText>
                    </CInputGroupPrepend>
                    <MultipleSelectDropdown
                      options={props.artists}
                      values={newMedium.artists || []}
                      valueKey="id"
                      textKey="name"
                      name="artistSelect"
                      onSelect={(values) => onSelectArtist('artists', values)}
                      onRemove={() => onSelectArtist('artists', [])}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["artistName"] ? <CInvalidFeedback>{errors["artistName"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <AutocompleteInput
                  className="col-12 row"
                  prependInput={
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Author</CInputGroupText>
                    </CInputGroupPrepend>
                  }
                  appendInput={
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  }
                  error={errors["authorName"]}
                  name="authorName"
                  onChange={onChangeValue}
                  suggestions={props.artists?.filter(a => a.professions.includes('Author'))?.map(a => a.name)}
                  value={newMedium.authorName}
                />
                <AutocompleteInput
                  className="col-12 row"
                  prependInput={
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Producer</CInputGroupText>
                    </CInputGroupPrepend>
                  }
                  appendInput={
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  }
                  error={errors["composerName"]}
                  name="composerName"
                  onChange={onChangeValue}
                  suggestions={props.artists?.filter(a => a.professions.includes('Composer'))?.map(a => a.name)}
                  value={newMedium.composerName}
                />
                <AutocompleteInput
                  className="col-12 row"
                  prependInput={
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Main Artist</CInputGroupText>
                    </CInputGroupPrepend>
                  }
                  appendInput={
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-user" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                  }
                  error={errors["artistName"]}
                  name="artistName"
                  onChange={onChangeValue}
                  suggestions={props.artists?.map(a => a.name)}
                  value={newMedium.artistName}
                /><CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CTooltip content={`Audio/Video max ${props.configs.fileFullMaxSize} MB`} placement="top-start">
                        <CInputGroupText style={{ width: "150px"}}>File Full <i className="far fa-question-circle pl-2"/></CInputGroupText>
                      </CTooltip>
                    </CInputGroupPrepend>
                    <div className={"form-control file-input" + (errors["fileFull"] ? ' is-invalid' : '')} onClick={() => openUpload('fileFull')} style={{ cursor: 'pointer' }}>
                      {newMedium?.fileFull || 'Choose File...'}
                      {!!files.fileFull &&
                        <CButton className="btn-remove-file" onClick={(e) => removeFile(e, 'fileFull')}>
                          <svg width="24" height="24" fill="none" stroke="currentColor" stroke-width="2" class="dropdown-search-clear-icon gray"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>
                        </CButton>
                      }
                    </div>
                    <input
                      type="file"
                      accept="video/*,audio/*"
                      id="fileFull"
                      name="fileFull"
                      hidden
                      onChange={uploadFile}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-audio" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["fileFull"] ? <CInvalidFeedback>{errors["fileFull"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CTooltip content={`Audio/Video max ${props.configs.fileIntroMaxSize} MB`} placement="top-start">
                        <CInputGroupText style={{ width: "150px"}}>File 15/30s <i className="far fa-question-circle pl-2"/></CInputGroupText>
                      </CTooltip>
                    </CInputGroupPrepend>
                    <div className={"form-control file-input" + (errors["fileIntro"] ? ' is-invalid' : '')} onClick={() => openUpload('fileIntro')} style={{ cursor: 'pointer' }}>
                      {newMedium?.fileIntro || 'Choose File...'}
                      {!!files.fileIntro &&
                        <CButton className="btn-remove-file" onClick={(e) => removeFile(e, 'fileIntro')}>
                          <svg width="24" height="24" fill="none" stroke="currentColor" stroke-width="2" class="dropdown-search-clear-icon gray"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>
                        </CButton>
                      }
                    </div>
                    <input
                      type="file"
                      accept="video/*,audio/*"
                      id="fileIntro"
                      name="fileIntro" hidden
                      onChange={uploadFile}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-audio" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["fileIntro"] ? <CInvalidFeedback>{errors["fileIntro"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CTooltip content={`Video max ${props.configs.fileMvMaxSize} MB`} placement="top-start">
                        <CInputGroupText style={{ width: "150px"}}>File MV <i className="far fa-question-circle pl-2"/></CInputGroupText>
                      </CTooltip>
                    </CInputGroupPrepend>
                    <div className={"form-control file-input" + (errors["fileMv"] ? ' is-invalid' : '')} onClick={() => openUpload('fileMv')} style={{ cursor: 'pointer' }}>
                      {newMedium?.fileMv || 'Choose File...'}
                      {!!files.fileMv &&
                        <CButton className="btn-remove-file" onClick={(e) => removeFile(e, 'fileMv')}>
                          <svg width="24" height="24" fill="none" stroke="currentColor" stroke-width="2" class="dropdown-search-clear-icon gray"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>
                        </CButton>
                      }
                    </div>
                    <input
                      type="file"
                      accept="video/*"
                      id="fileMv"
                      name="fileMv" hidden
                      onChange={uploadFile}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-audio" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["fileMv"] ? <CInvalidFeedback>{errors["fileMv"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CTooltip content={`Audio max ${props.configs.fileBeatMaxSize} MB`} placement="top-start">
                        <CInputGroupText style={{ width: "150px"}}>File Beat <i className="far fa-question-circle pl-2"/></CInputGroupText>
                      </CTooltip>
                    </CInputGroupPrepend>
                    <div className={"form-control file-input" + (errors["fileBeat"] ? ' is-invalid' : '')} onClick={() => openUpload('fileBeat')} style={{ cursor: 'pointer' }}>
                      {newMedium?.fileBeat || 'Choose File...'}
                      {!!files.fileBeat &&
                        <CButton className="btn-remove-file" onClick={(e) => removeFile(e, 'fileBeat')}>
                          <svg width="24" height="24" fill="none" stroke="currentColor" stroke-width="2" class="dropdown-search-clear-icon gray"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>
                        </CButton>
                      }
                    </div>
                    <input
                      type="file"
                      accept="audio/*"
                      id="fileBeat"
                      name="fileBeat" hidden
                      onChange={uploadFile}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-file-audio" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["fileBeat"] ? <CInvalidFeedback>{errors["fileBeat"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup>
                    <CInputGroupPrepend>
                      <CInputGroupText style={{ width: "150px"}} >Lyric</CInputGroupText>
                    </CInputGroupPrepend>
                    <CTextarea
                      onChange={onChangeValue}
                      value={newMedium ? newMedium.lyric : ''}
                      type="text"
                      id="lyric"
                      name="lyric"
                      invalid={!!errors["lyric"]}
                    />
                    <CInputGroupAppend>
                      <CInputGroupText><i className="fas fa-book-open" style={{ width: '20px' }}/></CInputGroupText>
                    </CInputGroupAppend>
                    {!!errors["lyric"] ? <CInvalidFeedback>{errors["lyric"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
                <CFormGroup className="col-12 row">
                  <CInputGroup className="mb-2">
                    {!!errors["general"] ? <CInput hidden invalid={!!errors["general"]} /> : ""}
                    {!!errors["general"] ? <CInvalidFeedback>{errors["general"]}</CInvalidFeedback> : ""}
                  </CInputGroup>
                </CFormGroup>
              </div>
            </CCardBody>
          </CCard>
        </CForm>
      </CModalBody>
      <CModalFooter>
        <CButton type="button" color="primary" onClick={onSave}>Save</CButton>
        <CButton type="button" color="secondary" onClick={props.cancel}>Cancel</CButton>
      </CModalFooter>
    </CModal>
  )
}

export default MediaForm