import {
  CButton,
  CDataTable,
  CCarousel,
  CCarouselInner,
  CCarouselItem,
} from '@coreui/react'

const fields = ['ID', 'Name', 'Cover', 'Genre', 'Singers', 'Contract Start', 'status', 'Edit']
const getBadge = status => {
  switch (status) {
    case 'New': return 'btn btn-secondary'
    case 'Edited': return 'btn btn-primary'
    case 'Processing': return 'btn btn-warning'
    case 'Completed': return 'btn btn-success'
    case 'Error': return 'btn btn-danger'
  }
}
const MediaTable = (props) => {
  return (
    <CDataTable
      items={props.media}
      fields={fields}
      dark
      hover
      striped
      // bordered
      size="sm"
      scopedSlots = {{
        'ID': (item)=>(
            <td style={{verticalAlign: "middle"}}>
              {item.id}
            </td>
          ),
        'Name': (item)=>(
            <td style={{verticalAlign: "middle"}}>
              {item.name}
            </td>
          ),
        'Cover': (item) => (
          <td >
            <CCarousel activeIndex={0}>
              <CCarouselInner>
                <CCarouselItem style={{ width: '100px' }}>
                  <img
                    className="d-block img-fluid"
                    src={item.images?.[0]
                      ? URL.createObjectURL(item.images[0])
                      : "https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png"
                    }
                    alt={`slide #1`}
                  />
                </CCarouselItem>
              </CCarouselInner>
            </CCarousel>
          </td>
        ),
        'Genre': (item)=>(
          <td style={{verticalAlign: "middle"}}>
            {item.genreCategory}
          </td>
        ),
        'Singers': (item)=>(
          <td style={{verticalAlign: "middle"}}>
            {item.artists?.map((artistId => (
              <div>{props.artists.find(a => a.id === artistId)?.name || ""}</div>
            )))}
          </td>
        ),
        // 'Author': (item)=>(
        //   <td style={{verticalAlign: "middle"}}>
        //     {item.authorName}
        //   </td>
        // ),
        // 'Producer': (item)=>(
        //   <td style={{verticalAlign: "middle"}}>
        //     {item.composerName}
        //   </td>
        // ),
        'Contract Start': (item)=>(
          <td style={{verticalAlign: "middle"}}>
            {item.contractStartDate || ""}
          </td>
        ),
        'status': (item) => (
          <td style={{verticalAlign: "middle"}}>
            <div className={getBadge(item.status)}>{item.status}</div>
          </td>
        ),
        'Edit': (item) => (
          <td style={{verticalAlign: "middle"}}>
            <CButton disabled={item.status === 'Completed'} color="info" style={{width: '60px'}} onClick={() => props.edit(item.id)}>Edit</CButton>
          </td>
        ),
      }}
    />
  )
}

export default MediaTable