import React, { useState, useEffect, useRef } from 'react'
import {
  CRow,
  CCol,
  CSpinner,
  CCard,
} from '@coreui/react'

import Header from './Header'
import Table from './Table'
import ClearModal from './ClearModal'
import NotiModal from './NotiModal'
import EditModal from './EditModal'
import { extractMedia } from './processUploadFile'
import { genresApi, artistsApi, providersApi, configsApi, mediaApi, contractsApi } from '../../../api'

const BulkUploadPage = (props) => {
  const ref = useRef(0);
  const [modals, setModals] = useState({
    clearModal: false,
    editModal: false,
    notiModal: false,
  })
  const [errors, setErrors] = useState({})
  const [isLoading, setLoading] = useState(false)
  const [media, setMedia] = useState([])
  const [notification, setNotification] = useState({
    message: '',
    level: 'info'
  })
  const [genres, setGenres] = useState([])
  const [contracts, setContracts] = useState([])
  const [providers, setProviders] = useState([])
  const [artists, setArtists] = useState([])
  const [configs, setConfigs] = useState({})
  const [editMedium, setEditMedium] = useState(null)

  useEffect(() => {
    const fetchGenres = async () => {
      const res = await genresApi.getListForSelect()
      if (!res.isError) {
        return setGenres(res.data.genres)
      }
    }
    const fetchContracts = async () => {
      const res = await contractsApi.getListForSelect()
      if (!res.isError) {
        return setContracts(res.data.contracts)
      }
    }
    const fetchArtirts = async () => {
      let res = await artistsApi.fetchArtistsAndGroup()
      if (!res.isError) {
        setArtists(res.data?.artists)
      }
    }
    const fetchProviders = async () => {
      const res = await providersApi.getListForSelect()
      if (!res.isError && res?.data?.providers) {
        setProviders(res.data.providers)
      }
    }
    const fetchConfigs = async () => {
      const res = await configsApi.getConfigs()
      if (!res.isError) {
        setConfigs(res.data.configs)
      }
    }

    fetchConfigs()
    fetchArtirts()
    fetchGenres()
    fetchProviders()
    fetchContracts()

    window.addEventListener('popstate', onBackButtonEvent)
    return () => {
      window.removeEventListener('popstate', onBackButtonEvent);
    };
  }, [])

  const onBackButtonEvent = (event) => {
    event.preventDefault()
    if (ref.current && !event.state) {
      if (window.confirm("There are some media have not processed yet! Do you want to go back?")) {
        // your logic
        ref.current = 0;
        window.removeEventListener('popstate', onBackButtonEvent)
        setTimeout(() => props.history.push(event?.target?.target?.location?.hash), 200)
      } else {
        window.history.pushState(true, null, window.location.origin + '/#/media/bulk-upload')
      }
    }
  }

  const showChoosingFileModal = (ignoreClear) => {
    if (!ignoreClear && media.find(m => m.status !== 'Completed')) {
      return setModals({...modals, clearModal: true})
    }
    closeModal('clearModal')
    setTimeout(() => document.getElementById('fileInput').click(), 100)
  }

  const closeModal = (modal) => {
    setModals({...modals, [modal]: false})
  }

  const chooseFile = async (e) => {
    if (e.target?.files?.[0]) {
      let file = e.target.files[0]
      let userInfo = localStorage.getItem('userProfile')
      document.getElementById('fileInput').value = ''
      let data = await extractMedia(file, genres, artists, providers, contracts, userInfo)

      if (data?.length > 0) {
        ref.current = 1
        return setMedia(data)
      }
      setNotification({
        message: 'Media list is empty or cannot be process!',
        level: 'warning'
      })
      setModals({...modals, notiModal: true})
    }
  }

  const openEditModal = (id) => {
    const medium = media.find(m => m.id === id)
    if (!medium) return
    setEditMedium(medium)
    setModals({...modals, editModal: true})
  }

  const saveEditMedium = (medium) => {
    medium.status = 'Edited'
    setMedia(media.map(m => m.id === medium.id ? medium : m))
    setModals({...modals, editModal: false})
    setEditMedium(null)
  }

  const validateAndAddAddnInfo = (medium) => {
    const submitMedium = {...medium}
    let validateErrors = {}
    if (!submitMedium.name) {
      validateErrors['name'] = 'Media name is required!'
    }
    if (submitMedium.genreCategory) {
      const genre = genres.find(g => g.categoryCodePath.trim() === submitMedium.genreCategory.trim())
      if (!genre) {
        validateErrors['genreCategory'] = 'Please select genre in dropdown!'
      } else {
        submitMedium.genres = [genre.id]
      }
    } else {
      delete submitMedium.genres
    }
    if (submitMedium.artistName) {
      const artist = artists?.find(a => a.name.trim() === submitMedium.artistName.trim())
      if (!artist) {
        validateErrors['artistName'] = 'Please select main artist in dropdown!'
      } else {
        submitMedium.artistId = artist.id
      }
    } else {
      delete submitMedium.artistId
    }
    if (submitMedium.authorName) {
      const artist = artists?.find(a => a.name.trim() === submitMedium.authorName.trim())
      if (!artist) {
        validateErrors['authorName'] = 'Please select author in dropdown!'
      } else {
        submitMedium.authors = [artist.id]
      }
    } else {
      delete submitMedium.authors
    }
    if (submitMedium.composerName) {
      const artist = artists?.find(a => a.name.trim() === submitMedium.composerName.trim())
      if (!artist) {
        validateErrors['composerName'] = 'Please select author in dropdown!'
      } else {
        submitMedium.composers = [artist.id]
      }
    } else {
      delete submitMedium.composers
    }
    if (submitMedium.contractId?.value) {
      const contract = contracts?.find(a => a.id === submitMedium.contractId?.value.trim())
      if (!contract) {
        validateErrors['contractId'] = 'Please select a contract in suggestion list!'
      } else {
        submitMedium.contractId = submitMedium?.contractId.value || null
      }
    } else {
      delete submitMedium.contractId
    }
    if (Object.values(validateErrors).length) return {errors: validateErrors, medium}

    return {errors: null, submitMedium}
  }

  const createMedium = async (medium) => {
    const { errors, submitMedium } = validateAndAddAddnInfo(medium)
    if (errors) {
      submitMedium.status = 'Error'
      return { errors, submitMedium }
    }
    let res = await mediaApi.create({
      ...submitMedium,
      status: 'active',
    })

    if (res.isError) {
      submitMedium.status = 'Error'
      let err = {general: res.errorMessage}
      return {errors: err, submitMedium}
    }

    submitMedium.status = 'Completed'
    return {submitMedium}
  }

  const bulkCreated = async () => {
    if (!media?.length) {
      setNotification({
        message: 'Media list is empty!',
        level: 'warning'
      })
      return setModals({...modals, notiModal: true})
    }
    setLoading(true)
    const newErrors = {...errors}
    let completedCount = 0
    await media.reduce(async (res, m, i) => {
      await res
      if (m.status === 'Completed') {
        completedCount++
        return
      }
      m.status = 'Processing'
      setMedia(media.map(medium => medium.id === m.id ? m : medium))
      const { errors: subErrors, submitMedium } = await createMedium(m)
      if (subErrors) {
        newErrors[m.id] = {...newErrors[m.id], ...subErrors}
        completedCount--
      }
      completedCount++
      m.status = submitMedium.status
      setMedia(media.map(medium => medium.id === m.id ? m : medium))
    }, Promise.resolve())

    setErrors(newErrors)
    setNotification({
      message: 'All media have processed',
      level: 'info'
    })
    setModals({
      ...modals,
      notiModal: true
    })

    if (completedCount === media.length) {
       ref.current = 0;
    }
    setLoading(false)
  }

  return (
    [<div className={"justify-content-center align-items-center custom-spinner custom-spinner-" + (isLoading ? "loading" : "stop")}>
      <CSpinner color="success" size="lg" style={{width: '4rem', height: '4rem'}}/>
    </div>,
    <ClearModal
      isShow={modals.clearModal}
      cancel={() => closeModal('clearModal')}
      yes={() => showChoosingFileModal(true)}
    />,
    <NotiModal
      isShow={modals.notiModal}
      cancel={() => closeModal('notiModal')}
      message={notification.message}
      className={notification.level}
    />,
    editMedium
    ? <EditModal
        isShow={modals.editModal}
        cancel={() => closeModal('editModal')}
        medium={editMedium}
        configs={configs}
        genres={genres}
        contracts={contracts}
        artists={artists || []}
        providers={providers}
        errors={errors[editMedium?.id] || {}}
        save={saveEditMedium}
      />
    : "",
    <CRow>
      <CCol>
        <CCard>
          <Header chooseFile={chooseFile} showChoosingFileModal={showChoosingFileModal} upload={bulkCreated} />
          <div className="p-3">
            <Table
              media={media}
              genres={genres}
              artists={artists}
              providers={providers}
              edit={openEditModal}
            />
          </div>
        </CCard>
      </CCol>
    </CRow>
    ]
  )
}

export default BulkUploadPage