import XLSX from 'xlsx';

const ExcelKeyMapping = {
  songName: 'name',
  isrcCode: 'isrc',
}

export const extractMedia = async (file, genres, artists, providers, contracts, userInfo) => {
  try {
    let userName = undefined;
    try {
      userInfo = JSON.parse(userInfo);
      userName = userInfo.name;
    }
    catch (err) {
      console.log({ERROR: err.message})
    }
    let data = await readExcelFile(file);
    data.forEach(medium => {
      matchGenres(medium, genres);
      matchArtists(medium, artists);
      matchProviders(medium, providers);
      let contract = contracts.find(c => c.id === medium?.contractId);
      if (contract) {
        medium.contractStartDate = contract?.startDate?.slice(0, 10);
        medium.contractEndDate = contract?.endDate?.slice(0, 10);
        medium.contractId = {label: contract.id, value: contract.id};
      }
      debugger
      Object.keys(ExcelKeyMapping).forEach(k => medium[ExcelKeyMapping[k]] = medium[k]);
      medium.initiatorName = userName;
      medium.status = 'New';
    })
    return data;
  } catch (err) {
    console.error(err);
  }
}

const matchGenres = (medium, genres) => {
  const mediumGenre = (medium.genre || '').replace(' / ', '/').trim().toLowerCase();
  if (!mediumGenre) return;
  const genre = genres.find((g) => {
    const genreLower = g.category?.toLowerCase();
    const pathGenreLowerCase = g.categoryCodePath?.replace(' / ', '/').toLowerCase();

    return mediumGenre === genreLower || pathGenreLowerCase?.includes(mediumGenre);
  })
  if (!genre) return;
  medium.genreCategory = genre.categoryCodePath;
}

const matchArtists = (medium, artists) => {
  const singers = (medium.singers || '').split(/\n+/g).map(s => findArtist(s, artists)).filter(s => !!s);
  const author = findArtist(medium.author || '', artists.filter(a => a.professions.includes('Author')))
  const producer = findArtist(medium.producer || '', artists.filter(a => a.professions.includes('Composer')))
  const mainArtist = findArtist(medium.mainArtist || '', artists);
  if (singers?.length) {
    medium.artists = singers.map(s => s.id);
  }
  if (author) {
    medium.authorName = author.name;
  }
  if (author) {
    medium.composerName = producer.name;
  }
  if (author) {
    medium.artistName = mainArtist.name;
  }
  return;
}

const findArtist = (name, artists) => {
  if (!name) return;
  return artists.find((a) => {
    return a.name.trim().replace(/\s+/g, ' ').toLowerCase() === name.trim().replace(/\s+/g, ' ').toLowerCase();
  })
}

const matchProviders = (medium, providers) => {
  let providerId = medium?.providerId;
  if (medium?.providerId) return;
  let providerName = medium?.providerName?.trim().toLowerCase().replace(/\s+/g, ' ');
  if (!providerName) return;
  const provider = providers.find((p) => {
    const name = p.name?.trim()?.toLowerCase().replace(/\s+/g, ' ');

    return name === providerName;
  })
  if (!provider) return;
  medium.providerId = provider.id;
  return;
}

const readExcelFile = (file, sheetName, options) => {
  return new Promise((resolve, reject) => {
    var reader = new FileReader();
    reader.onload = (e) => {
      var data = e.target.result;
      let readedData = XLSX.read(data, {type: 'binary'});
      sheetName = !sheetName ? readedData.SheetNames[0] : sheetName;
      /* Convert array to json*/
      const sheet0 = XLSX.utils.sheet_to_json(readedData.Sheets[sheetName], options ? options : {});

      return resolve(sheet0);
    };
    reader.onerror = e => reject(e);
    reader.readAsBinaryString(file);
  })
}