import React, { useState, useEffect } from 'react'
import { useLocation } from 'react-router-dom'
import {
  CSpinner
} from '@coreui/react'
import MediaList from './list/List'
import { mediaApi, artistsApi, configsApi } from '../../api'

const MediaManagement = (props) => {
  const [isLoading, setLoading] = useState(false)
  const limit = 5
  const [media, setMedia] = useState([])
  const [channels, setChannels] = useState([])
  const [artists, setArtists] = useState([])
  const queryPage = useLocation().search.match(/page=([0-9]+)/, '')
  const [count, setCount] = useState(10)
  const [filter, setFilter] = useState({
    name: "",
    artistName: "",
    contractDate: {
      startDate: null,
      endDate: null
    },
    createdAt: {
      startDate: null,
      endDate: null
    }
  })
  const currentPage = Number(queryPage && queryPage[1] ? queryPage[1] : 1)
  const [page, setPage] = useState(currentPage || 1)

  const pageChange = newPage => {
    if ((newPage || 1) === page) return
    fetchMedia(filter, newPage)
  }

  useEffect(() => {
    const fetchArtists = async () => {
      let suggestedArtists = await artistsApi.fetchArtistsForSuggesstions()
      setArtists(suggestedArtists)
    }
    const fetchConfigs = async () => {
      let res = await configsApi.getConfigs()
      if (!res.isError) {
        setChannels(res.data?.channels || [])
      }
    }
    fetchMedia({}, currentPage, true)
    fetchArtists()
    fetchConfigs()
  }, [])

  const onSearch = (fieldName, value) => {
    let newFilter = {...filter, [fieldName]: value}
    setFilter(newFilter)

    fetchMedia(newFilter, 1, true)
  }

  const fetchMedia = async (filter, page, fetchCount) => {
    setLoading(true)
    let res = await mediaApi.getList({...filter, limit, page, fetchCount})
    setLoading(false)
    if (!res.isError) {
      setPage(page)
      let {media, count} = res.data
      setMedia(media.map((m) => {
        let images = m.images?.map(f => f?.thumbnailPath || f?.filePath)
        delete m.images
        m.images = images
        return m
      }))
      if (fetchCount) setCount(count)
    }
  }

  const onEdit = (id) => {
    props.history.push('/media/'+id)
  }

  const onDownload = (filePath) => {
    let link = document.createElement("a")
    // If you don't know the name or want to use
    // the webserver default set name = ''
    let fileName = filePath.split('/').reverse()[0].split('?')[0]
    link.setAttribute('download', fileName)
    link.setAttribute('target', '_blank')
    link.href = filePath
    document.body.appendChild(link)
    link.click()
    link.remove()
  }
  const editStatus = async (id, status) => {
    let update = {
      status: status === 'active' ? status : 'inactive'
    }
    setLoading(true)
    let res = await mediaApi.editStatus(id, update.status)
    setLoading(false)
    if (!res.isError) {
      setMedia(media.map((p) => {
        if (p.id === id) p.status = status
        return p
      }))
    }
  }

  const editChannels = async (id, enabledChannels) => {
    setLoading(true)
    let res = await mediaApi.editChannels(id, enabledChannels)
    setLoading(false)
    if (!res.isError) {
      setMedia(media.map((p) => {
        if (p.id === id) p.availableChannels = enabledChannels
        return p
      }))
    }
  }

  const onRemove = async (id) => {
    return editStatus(id, 'removed')
  }
  const onDeactive = async (id) => {
    return editStatus(id, 'inactive')
  }
  const onActive = async (id) => {
    return editStatus(id, 'active')
  }

  return (
    [<div className={"justify-content-center align-items-center custom-spinner custom-spinner-" + (isLoading ? "loading" : "stop")}>
      <CSpinner color="success" size="lg" style={{width: '4rem', height: '4rem'}}/>
    </div>,
    <MediaList
      {...props}
      media={media}
      onDownload={onDownload}
      onEdit={onEdit}
      onActive={onActive}
      onDeactive={onDeactive}
      onRemove={onRemove}
      editChannels={editChannels}
      page={page}
      pages={Math.ceil(count / limit)}
      limit={limit}
      channels={channels}
      pageChange={pageChange}
      search={onSearch}
      artists={artists}
    />]
  )
}

export default MediaManagement;