import React, { useState } from 'react'
import {
  CBadge,
  CCard,
  CCardBody,
  CCardHeader,
  CCol,
  CDataTable,
  CRow,
  CDropdownToggle,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CDropdownDivider,
  CCarousel,
  CCarouselInner,
  CCarouselItem,
  CButton,
  CPagination
} from '@coreui/react'
import Search from '../../../containers/Search'
import EditChannelsModal from './EditChannelsModal'

const getBadge = status => {
  switch (status) {
    case 'active': return 'success'
    case 'inactive': return 'secondary'
    case 'pending': return 'warning'
    case 'removed': return 'danger'
    default: return 'primary'
  }
}
const fields = ['id', 'image', 'name', 'artist', 'views', 'channels', 'status', 'download', 'action']

const Tables = (props) => {
  const [showEditModal, setShowEditModal] = useState(false)
  const [medium, setMedium] = useState(null)
  const onRegister = () => {
    props.history.push('/media/new')
  }
  const onBulkUpload = () => {
    props.history.push('/media/bulk-upload')
  }
  const onSearch = (name, value) => {
    props.search(name, value)
  }

  const openEditChannels = (id) => {
    let medium = props.media.find(m => m.id === id)
    setMedium(medium)
    setShowEditModal(true)
  }
  const closeModal = () => {
    setMedium(null)
    setShowEditModal(false)
  }

  const editChannels = async (id, channels) => {
    await props.editChannels(id, channels)
    setMedium(null)
    setShowEditModal(false)
  }

  return [
    medium
    ? <EditChannelsModal
        isShow={showEditModal}
        cancel={closeModal}
        medium={medium}
        channels={props.channels}
        save={editChannels}
      />
    : "",
    <CRow>
      <CCol>
        <CCard>
          <CCardHeader align="center">
            <h1 style={{ display: 'inline-block' }}>Media List</h1>
            <CButton
              onClick={onBulkUpload}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(50% - 202px)' }}
            >
              Bulk Upload
            </CButton>
            <CButton
              onClick={onRegister}
              color="success"
              style={{ position: "relative", top: '-5px', left: 'calc(50% - 192px)' }}
            >
              Single Upload
            </CButton>
          </CCardHeader>
          <CCardBody>
            <Search
              items={[{
                name: "status",
                type: "select",
                placeholder: "Status",
                options: [{
                  value: 'active',
                  text: 'Active',
                },{
                  value: 'inactive',
                  text: 'Inactive',
                }],
              }, {
                name: "name",
                type: "text",
                placeholder: "Media Name...",
              }, {
                name: "artistName",
                type: "text",
                placeholder: "Artist Name...",
                gridSize: 2,
                autocomplete: true,
                suggestions: props.artists
              }, {
                name: "contractDate",
                type: "dateRange",
                placeholder: "Contract Date",
                field: 'Contract',
                gridSize: 3
              }, {
                name: "createdAt",
                type: "dateRange",
                placeholder: "Upload Date",
                field: 'Upload',
                gridSize: 3
              }]}
              search={onSearch}
            />
            <CDataTable
              items={props.media}
              fields={fields}
              dark
              hover
              striped
              // bordered
              size="sm"
              itemsPerPage={props.limit}
              activePage={props.page}
              pagination
              scopedSlots = {{
                'id':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.id}
                    </td>
                  ),
                'image': (item) => (
                  <td >
                    <CCarousel activeIndex={0}>
                      <CCarouselInner>
                        <CCarouselItem style={{ width: '100px' }}>
                          <img
                            className="d-block img-fluid"
                            src={item.images[0] || "https://www.seekpng.com/png/detail/110-1100707_person-avatar-placeholder.png"}
                            alt={`slide #1`}
                          />
                        </CCarouselItem>
                      </CCarouselInner>
                    </CCarousel>
                  </td>
                ),
                'name':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.name}
                    </td>
                  ),
                'artist':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.mainArtist?.fullName || item.mainArtist?.name || item.mainArtist?.fullName || item.artists[0]?.name || 'Unknown'}
                    </td>
                  ),
                // 'composer':
                //   (item)=>(
                //     <td style={{verticalAlign: "middle"}}>
                //       {item.composers.map(a => a.name).join(' - ') || 'Unknown'}
                //     </td>
                //   ),
                // 'author':
                //   (item)=>(
                //     <td style={{verticalAlign: "middle"}}>
                //       {item.authors.map(a => a.name).join(' - ') || 'Unknown'}
                //     </td>
                //   ),
                'views':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      {item.views?.reduce((v, a) => v + a.count, 0) || 0}
                    </td>
                  ),
                'channels':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}} className="cursor-pointer" onClick={() => openEditChannels(item.id)}>
                      {item.availableChannels > 0
                        ? Object.keys(props.channels).filter(c => props.channels[c] & item.availableChannels).map((c, k) => (
                          <div className="btn btn-success d-block my-1" key={k}>{c}</div>
                        ))
                        : <div className="btn btn-secondary">No Channels</div>
                      }
                    </td>
                  ),
                'status':
                  (item)=>(
                    <td style={{verticalAlign: "middle"}}>
                      <CDropdown className="m-1 btn-group" style={{width: '100px'}}>
                        <CDropdownToggle color={getBadge(item.status)}>
                            {item.status}
                        </CDropdownToggle>
                        <CDropdownMenu>
                          <CDropdownItem onClick={() => props.onActive(item.id)} className="success">Active</CDropdownItem>
                          <CDropdownItem onClick={() => props.onDeactive(item.id)} className="remove">Deactive</CDropdownItem>
                        </CDropdownMenu>
                      </CDropdown>
                    </td>
                  ),
                'action': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    <CButton color="secondary" style={{width: '100px'}} onClick={() => props.onEdit(item.id)}>Edit</CButton>
                  </td>
                ),
                'download': (item) => (
                  <td style={{verticalAlign: "middle"}}>
                    {
                      !!item.fileFull?.filePath &&
                      <div>
                        <a
                          target="_blank"
                          download={item.fileFull.filePath.split('/').reverse()[0].split('?')[0]}
                          href={item.fileFull.filePath}
                          style={{color: "#5aea8b"}}
                        >
                          <span className="fas fa-arrow-circle-down pr-2"></span>
                          File Full
                        </a>
                      </div>
                    }
                    {
                      !!item.fileIntro?.filePath &&
                        <div>
                          <a
                            target="_blank"
                            download={item.fileIntro.filePath.split('/').reverse()[0].split('?')[0]}
                            href={item.fileIntro.filePath}
                            style={{color: "#5aea8b"}}
                          >
                            <span className="fas fa-arrow-circle-down pr-2"></span>
                            File Intro
                          </a>
                        </div>
                    }
                  </td>
                )
              }}
            />
          <CPagination
            activePage={props.page}
            onActivePageChange={props.pageChange}
            pages={props.pages}
            doubleArrows={false}
            align="center"
          />
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  ]
}

export default Tables