import React, { useState } from 'react'
import {
  CButton,
  CCard,
  CCardBody,
  CCardGroup,
  CCol,
  CContainer,
  CForm,
  CInput,
  CInputGroup,
  CInputGroupPrepend,
  CInputGroupText,
  CRow,
  CInvalidFeedback
} from '@coreui/react'
import CIcon from '@coreui/icons-react'
import { authApi } from '../../../api'

const Login = (props) => {
  const initBody = {
    userName: '',
    password: ''
  }
  const [body, setBody] = useState(initBody)
  const [error, setError] = useState('')

  const onLogin = async () => {
    let response = await authApi.login(body)
    if (response.isError) {
      setError(response.errorMessage)
    } else {
      props.history.push('/dashboard')
    }
  }

  const onChangeValue = (e) => {
    let { name, value } = e.target
    setBody({...body, [name]: value})
    setError('')
  }

  const keyDown = (e) => {
    switch (e.key) {
      case 'Enter': {
        return onLogin()
      }
      default: return
    }
  }

  const onForgetPassword = (e) => {

  }

  return (
    <div className="c-app c-default-layout flex-row align-items-center">
      <CContainer>
        <CRow className="justify-content-center">
          <CCol md="6">
            <CCardGroup>
              <CCard className="p-4">
                <CCardBody>
                  <CForm>
                    <h1>Login</h1>
                    <p className="text-muted">Sign In to your account</p>
                    <CInputGroup className="mb-3">
                      <CInputGroupPrepend>
                        <CInputGroupText>
                          <CIcon name="cil-user" />
                        </CInputGroupText>
                      </CInputGroupPrepend>
                      <CInput
                        type="text"
                        placeholder="User's name"
                        name="userName"
                        value={body.userName}
                        onChange={onChangeValue}
                        autoComplete=""
                        onKeyDown={keyDown}
                      />
                    </CInputGroup>
                    <CInputGroup className="mb-2">
                      <CInputGroupPrepend>
                        <CInputGroupText>
                          <CIcon name="cil-lock-locked" />
                        </CInputGroupText>
                      </CInputGroupPrepend>
                      <CInput
                        type="password"
                        name="password"
                        placeholder="Password"
                        value={body.password}
                        onChange={onChangeValue}
                        autoComplete=""
                        onKeyDown={keyDown}
                      />
                    </CInputGroup>
                    <CInputGroup className="mb-4">
                      {!!error ? <CInput hidden invalid={!!error} /> : ""}
                      {!!error ? <CInvalidFeedback>{error}</CInvalidFeedback> : ""}
                    </CInputGroup>
                    <CRow>
                      <CCol xs="3">
                        <CButton color="primary" className="px-5" onClick={onLogin}>Login</CButton>
                      </CCol>
                      {/* <CCol xs="5">
                        <CButton color="info" className="px-4" onClick={onRegister}>Register Now!</CButton>
                      </CCol> */}
                      <CCol xs="9" className="text-right">
                        <CButton color="link" className="px-0" onClick={onForgetPassword}>Forgot password?</CButton>
                      </CCol>
                    </CRow>
                  </CForm>
                </CCardBody>
              </CCard>
            </CCardGroup>
          </CCol>
        </CRow>
      </CContainer>
    </div>
  )
}

export default Login
