import React, { useEffect, useState } from 'react'
import { useLocation } from 'react-router-dom'
import {
  CSpinner
} from '@coreui/react'
import ProviderList from './list/List'
import { providersApi } from '../../api'

const ProviderManagement = (props) => {
  const [isLoading, setLoading] = useState(false)
  const [providers, setProviders] = useState([])
  const limit = 10
  const [filter, setFilter] = useState({})
  const queryPage = useLocation().search.match(/page=([0-9]+)/, '')
  const [count, setCount] = useState(10)
  const currentPage = Number(queryPage && queryPage[1] ? queryPage[1] : 1)
  const [page, setPage] = useState(currentPage)

  const pageChange = newPage => {
    if ((newPage || 1) === page) return
    fetchProviders(filter, newPage)
  }

  useEffect(() => {
    fetchProviders({}, currentPage, true)
  }, [])

  const fetchProviders = async (filter, page, fetchCount) => {
    setLoading(true)
    let res = await providersApi.getList({...filter, limit, page, fetchCount})
    setLoading(false)
    if (!res.isError) {
      setPage(page)
      let {providers, count} = res.data
      setProviders(providers.map((p) => {
        let image = p.profileImage?.thumbnailPath || p.profileImage?.filePath
        delete p.profileImage
        p.image = image
        return p
      }))
      if (fetchCount) setCount(count)
    }
  }

  const onEdit = (id) => {
    props.history.push('/providers/'+id)
  }
  const editStatus = async (id, status) => {
    let update = {
      status: status === 'active' ? status : 'inactive'
    }
    setLoading(true)
    let res = await providersApi.editStatus(id, update.status)
    setLoading(false)
    if (!res.isError) {
      setProviders(providers.map((p) => {
        if (p.id === id) p.status = status
        return p
      }))
    }
  }
  const onRemove = async (id) => {
    return editStatus(id, 'removed')
  }
  const onDeactive = async (id) => {
    return editStatus(id, 'inactive')
  }
  const onActive = async (id) => {
    return editStatus(id, 'active')
  }

  const onSearch = (fieldName, value) => {
    let newFilter = {...filter, [fieldName]: value}
    setFilter(newFilter)

    fetchProviders(newFilter, 1, true)
  }

  return (
    [ <div className={"justify-content-center align-items-center custom-spinner custom-spinner-" + (isLoading ? "loading" : "stop")}>
        <CSpinner color="success" size="lg" style={{width: '4rem', height: '4rem'}}/>
      </div>,
      <ProviderList
        {...props}
        providers={providers}
        onEdit={onEdit}
        onRemove={onRemove}
        onDeactive={onDeactive}
        onActive={onActive}
        page={page}
        pages={Math.ceil(count / limit)}
        limit={limit}
        pageChange={pageChange}
        search={onSearch}
      />
    ]
  )
}

export default ProviderManagement;