import React, {useState, useEffect} from 'react'
import { CCard, CCardBody, CCardHeader, CCol, CRow, CButton } from '@coreui/react'
import { authApi } from '../../api'

const User = () => {
  const [user, setUser] = useState({})
  const userFields = [{
    field: 'name',
    text: 'Full Name',
  },{
    field: 'userName',
    text: 'User Name',
  },{
    field: 'email',
    text: 'Email',
  },{
    field: 'role',
    text: 'Role',
  },{
    field: 'providerName',
    text: 'Provider',
  }]

  useEffect(() => {
    const fetchUser = async () => {
      let res = await authApi.checkAuth()
      if (!res.isError) {
        const user = res.data
        user.providerName = user.provider?.name
        setUser(user)
      }
    }

    fetchUser()
  }, [])

  const logout = () => {
    authApi.logout()
  }

  return (
    <CRow className="justify-content-center">
      <CCol lg={8} className="justify-content-center">
        <CCard>
          <CCardHeader>
            User id: {user?.id}
          </CCardHeader>
          <CCardBody>
              <table className="table table-striped table-hover">
                <tbody>
                  {
                    userFields.map(({ field, text }, index) => {
                      return (
                        <tr key={index.toString()}>
                          <td>{`${text}:`}</td>
                          <td><strong>{user[field]}</strong></td>
                        </tr>
                      )
                    })
                  }
                </tbody>
              </table>
          </CCardBody>
          <CCol className="row justify-content-center">
            <CButton className="col-4 mb-4" color="danger" block type="button" onClick={logout}>
              Logout
            </CButton>
          </CCol>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default User
