import React, {useState, useEffect} from 'react'
import { CCard, CCardBody, CCardHeader, CCol, CRow } from '@coreui/react'
import CIcon from '@coreui/icons-react'
import { usersApi } from '../../api'

const User = (props) => {
  const { match: {params: { id }} } = props
  const [user, setUser] = useState(null)
  useEffect(() => {
    const fetchUser = async () => {
      let res = await usersApi.getOne(id)
      if (!res.isError) {
        setUser(res.data)
      }
    }

    fetchUser()
  }, [])

  const userDetails = user ? Object.entries(user) :
    [['id', (<span><CIcon className="text-muted" name="cui-icon-ban" /> Not found</span>)]]

  return (
    <CRow className="justify-content-center">
      <CCol lg={8}>
        <CCard>
          <CCardHeader>
            User id: {id}
          </CCardHeader>
          <CCardBody>
              <table className="table table-striped table-hover">
                <tbody>
                  {
                    userDetails.filter(([, v]) => !!v).map(([key, value], index) => {
                      return (
                        <tr key={index.toString()}>
                          <td>{`${key}:`}</td>
                          <td><strong>{value}</strong></td>
                        </tr>
                      )
                    })
                  }
                </tbody>
              </table>
          </CCardBody>
        </CCard>
      </CCol>
    </CRow>
  )
}

export default User
