import React, { useEffect, useState } from 'react'
import {
  CWidgetDropdown,
  CRow,
  CCol,
  CDropdown,
  CDropdownMenu,
  CDropdownItem,
  CDropdownToggle
} from '@coreui/react'
import CIcon from '@coreui/icons-react'
import ChartLineSimple from '../charts/ChartLineSimple'
import ChartBarSimple from '../charts/ChartBarSimple'

import { dashboardApi } from '../../api'

const WidgetsDropdown = () => {
  const [data, setData] = useState({
    providers: [],
    artists: [],
    albums: [],
    media: []
  })
  const [size, setSize] = useState(3)

  useEffect(() => {
    const fetchStatistics = async () => {
      const res = await dashboardApi.getTotalResources()
      if (!res.isError) {
        setData(res.data.resources)
        setSize(res.data.resources.providers ? 3 : 4)
      }
    }

    fetchStatistics()
  }, [])
  // render
  return (
    <CRow>
      {!!data.providers?.length &&
        <CCol className={"col-" + size}>
          <CWidgetDropdown
            color="gradient-primary"
            header={data.providers[data.providers.length - 1]}
            text="Providers"
            footerSlot={
              <ChartLineSimple
                pointed
                className="c-chart-wrapper mt-3 mx-3"
                style={{height: '70px'}}
                dataPoints={data.providers}
                pointHoverBackgroundColor="primary"
                label="Providers"
                labels="months"
              />
            }
          >
            <CDropdown>
              <CDropdownToggle color="transparent">
                <CIcon name="cil-settings"/>
              </CDropdownToggle>
              {/* <CDropdownMenu className="pt-0" placement="bottom-end">
                <CDropdownItem>Action</CDropdownItem>
                <CDropdownItem>Another action</CDropdownItem>
                <CDropdownItem>Something else here...</CDropdownItem>
                <CDropdownItem disabled>Disabled action</CDropdownItem>
              </CDropdownMenu> */}
            </CDropdown>
          </CWidgetDropdown>
        </CCol>
      }
      {!!data.media?.length &&
        <CCol className={"col-" + size}>
          <CWidgetDropdown
            color="gradient-info"
            header={data.media[data.media.length - 1]}
            text="Media"
            footerSlot={
              <ChartLineSimple
                pointed
                className="mt-3 mx-3"
                style={{height: '70px'}}
                dataPoints={data.media}
                pointHoverBackgroundColor="info"
                options={{ elements: { line: { tension: 0.00001 }}}}
                label="Media"
                labels="months"
              />
            }
          >
            <CDropdown>
              <CDropdownToggle caret={false} color="transparent">
                <CIcon name="cil-location-pin"/>
              </CDropdownToggle>
              {/* <CDropdownMenu className="pt-0" placement="bottom-end">
                <CDropdownItem>Action</CDropdownItem>
                <CDropdownItem>Another action</CDropdownItem>
                <CDropdownItem>Something else here...</CDropdownItem>
                <CDropdownItem disabled>Disabled action</CDropdownItem>
              </CDropdownMenu> */}
            </CDropdown>
          </CWidgetDropdown>
        </CCol>
      }
      {!!data.albums?.length &&
        <CCol className={"col-" + size}>
          <CWidgetDropdown
            color="gradient-warning"
            header={data.albums[data.albums.length - 1]}
            text="Albums"
            footerSlot={
              <ChartLineSimple
                className="mt-3"
                style={{height: '70px'}}
                backgroundColor="rgba(255,255,255,.2)"
                dataPoints={data.albums}
                options={{ elements: { line: { borderWidth: 2.5 }}}}
                pointHoverBackgroundColor="warning"
                label="Albums"
                labels="months"
              />
            }
          >
            <CDropdown>
              <CDropdownToggle color="transparent">
                <CIcon name="cil-settings"/>
              </CDropdownToggle>
              {/* <CDropdownMenu className="pt-0" placement="bottom-end">
                <CDropdownItem>Action</CDropdownItem>
                <CDropdownItem>Another action</CDropdownItem>
                <CDropdownItem>Something else here...</CDropdownItem>
                <CDropdownItem disabled>Disabled action</CDropdownItem>
              </CDropdownMenu> */}
            </CDropdown>
          </CWidgetDropdown>
        </CCol>
      }
      {!!data.artists?.length &&
        <CCol className={"col-" + size}>
          <CWidgetDropdown
            color="gradient-danger"
            header={data.artists[data.artists.length - 1]}
            text="Artists"
            footerSlot={
              <ChartBarSimple
                className="mt-3 mx-3"
                style={{height: '70px'}}
                dataPoints={data.artists}
                backgroundColor="rgb(250, 152, 152)"
                label="Artists"
                labels="months"
              />
            }
          >
            <CDropdown>
              <CDropdownToggle caret className="text-white" color="transparent">
                <CIcon name="cil-settings"/>
              </CDropdownToggle>
              {/* <CDropdownMenu className="pt-0" placement="bottom-end">
                <CDropdownItem>Action</CDropdownItem>
                <CDropdownItem>Another action</CDropdownItem>
                <CDropdownItem>Something else here...</CDropdownItem>
                <CDropdownItem disabled>Disabled action</CDropdownItem>
              </CDropdownMenu> */}
            </CDropdown>
          </CWidgetDropdown>
        </CCol>
      }
    </CRow>
  )
}

export default WidgetsDropdown
